**1.1.1 - 7/16/2025**

  - Bugfix: fix broken pip install --dry-run call in get_vbu_version.py

**1.1.0 - 7/15/2025**

  - Allow for pinning in other repos

**1.0.0 - 7/8/2025**

  - Initial major release

**0.1.0 - 7/8/2025**

  - Initial rc release
